/**
 * The Carrot class represents a vegetable that can be consumed by the kobold,
 * which increases its statuses.
 */
function Carrot() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Carrot";
    var itemDescription = "A taste-lacking vegetable. Good for your eyes.";
    var baseValue = 5;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You bite into the carrot,
                            tearing off the tip using your sharp teeth.
                            It's hard, it's cold, and it doesn't taste like much,
                            but at least it's food.
                            You thoroughly chew the carrot-piece, before swallowing it down and taking another bite.
                        [/p]
                        [p]
                            The coolness of the vegetable makes it feel quite [i]refreshing[/i].
                            You can see why rabbits and other animals love these things so much.
                            You chow down nibble after nibble, until you reach the end of the orange stick.
                            Overall, while not too [i]satisfying[/i] to eat, and not nearly enough to sate your hunger completely,
                            it provided some much-needed nutrition, energy for you to keep on trucking, be it towards glory or defeat.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.CARROT;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 175px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(5, "Ate a carrot");
        global.kobold.status.mental.increase(3, "Ate a carrot");
        global.kobold.status.stamina.increase(5, "Ate a carrot");
        global.kobold.status.exertion.decrease(5, "Ate a carrot");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +5),
            new Change("Food", "Sanity", +3),
            new Change("Food", "Stamina", +5),
            new Change("Food", "Sexual exhaustion", -5, true)
        ]);
        global.ui.showFullscreenPopup(contents);
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Consumable-stripped} consumable A Consumable object, stripped of private members and all functions.
     */
    this.load = function (consumable) {

    };
}
