/**
 * The Ham class represents a meal that can be consumed by the kobold,
 * which increases its statuses.
 */
function Ham() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Ham";
    var itemDescription = "A chunk of ham, with several slices missing.";
    var baseValue = 8;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            A good old piece of [b]meat[/b].
                            You can't remember the last time you had something like this.
                            You bring the preserved swine-leg to your mouth, and bite off a large piece of it.
                            Salty and well-seasoned, if a little too stringy for your tastes.
                            Beats eating raw meat off of an animal carcass, though.
                        [/p]
                        [p]
                            You thoroughly chew the mouthful you bit off, swallowing it before chomping down once again.
                            You settle into a slow rhythm of biting, savoring, processing and swallowing chunk after chunk of ham.
                            All too soon, the entire piece of meat is gone.
                            While a bit monotonous, you can't say you [b]didn't[/b] enjoy it.
                            In fact, it was [b]very[/b] good compared to other stuff you've eaten!
                            Overall, you've had a nice, filling, energy-packed meal that has left you lusting for more.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.HAM;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(6, "Ate ham");
        global.kobold.status.mental.increase(6, "Ate ham");
        global.kobold.status.stamina.increase(6, "Ate ham");
        global.kobold.status.exertion.decrease(6, "Ate ham");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +6), 
            new Change("Food", "Sanity", +6),
            new Change("Food", "Stamina", +6),
            new Change("Food", "Sexual exhaustion", -6, true)
        ]);
        global.ui.showFullscreenPopup(contents);
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
