/**
 * The Plum class represents a fruit that can be consumed by the kobold,
 * which increases its statuses.
 */
function Plum() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Plum";
    var itemDescription = "A medium-sized, purple fruit. Tasty. Eat it!";
    var baseValue = 6;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You bite into the purple fruit, taking out a large chunk of delicious, ripe, juicy goodness.
                            Tastes pretty darn great!
                            You delight in the flavor while chewing the mulchy goodness,
                            before swallowing it down.
                        [/p]
                        [p]
                            Your first mouthful is soon followed by a second, a third.
                            After the fourth bite, all that is left of the plum is core, which you scrape clean of any remaining fruity innards, before discarding it.
                            The plum didn't do much to sate your hunger, but it was very yummy nonetheless!
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.PLUM;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 165px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(2, "Ate a plum");
        global.kobold.status.mental.increase(5, "Ate a plum");
        global.kobold.status.stamina.increase(2, "Ate a plum");
        global.kobold.status.exertion.decrease(2, "Ate a plum");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +2),
            new Change("Food", "Sanity", +5),
            new Change("Food", "Stamina", +2),
            new Change("Food", "Sexual exhaustion", -2, true)
        ]);
        global.ui.showFullscreenPopup(contents);
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {Consumable-stripped} consumable A Consumable object, stripped of private members and all functions.
     */
    this.load = function (consumable) {

    };
}
