/**
 * The CharismaPotion class represents a potion that can be consumed by the kobold,
 * which increases its charisma stat.
 */
function CharismaPotion() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Charisma Potion";
    var itemDescription = "A glass flask. Purple liquid sloshes within. The label on the side says that it'll make you more charismatic.";
    var baseValue = 50;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You pop the lid of the potion, bring it to your snout, and cautiously sniff the contents. 
                            The purple fluid within smells fruity, like a bunch of squished berries.
                            Like grape juice before being turned into wine.
                        [/p]
                        [p]
                            While you enjoy the scent, you doubt the potion is a simple fruit-extract.
                            Emboldened by the natural fragrance, you lower the vial to your slightly parted lips, before tipping it backwards, 
                            along with your head, letting the contents flood into your mouth.
                        [/p]
                        [p]
                            The fluid tastes [b]exactly[/b] the way it smells, just like grape juice!
                            If it were a [i]little bit[/i] sweeter, or maybe a little fermented, you might even call this stuff a [i]good[/i] beverage.
                            Still, it beats water, your usual refreshment of choice.
                            And it's [b]definitely[/b] better than that one time you were forced to lap someone's spilled drink off of a filthy tavern floor.
                        [/p]
                        [p]
                            You gulp down the contents of the flask, down to the last droplet.
                            The liquid seems to [i]massage[/i] your throat as you swallow it.
                            It feels [i]soothing[/i] and [i]relieving[/i],
                            as though undoing the damage of a lifetime's worth of talking and shouting and screaming and yelling.
                        [/p]
                        [p]
                            Passing your throat and settling in your stomach, the feeling changes.
                            It becomes [i]odd[/i].
                            [i]Different[/i] from anything you've ever felt before.
                            Like it's not just [i]healing[/i] you, but also [i]changing[/i] something about you.
                            Something that you can't quite put your finger on.
                        [/p]
                        [p]
                            While you're certain this change is for the best, you can't quite help but dislike the sensation.
                            You [i]do[/i] feel a bit more confident in your ability to talk to people, but doubts still linger in your mind.
                            The potion has somewhat altered your very [b]personality[/b].
                            At what point will you stop being [i]you[/i], and instead become whatever [i]it[/i] wants you to be?
                        [/p]
                        [p]
                            [b]You have gained 1 charisma.[/b] [sneak]But at what cost?[/sneak]
                        [/p]`;
        return global.parser.parse(content);
    }
    
    /**
     * Builds and returns the consume popup contents when maxed out.
     * @returns {string} The consume popup contents when maxed out.
     */
    function buildMaxContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You are already as charismatic as you're ever going to get. You do not drink the potion.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.CHARISMA_POTION;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 200px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     * @returns {boolean} True if the consumable was consumed. False otherwise.
     */
    this.consume = function () {
        var cha = global.kobold.stats.get(StatsEnum.CHARISMA);
        var maxed = (cha >= global.kobold.stats.statMax);
        if (maxed) {
            global.ui.showFullscreenPopup(buildMaxContents());
            return false;
        }
        global.kobold.stats.increaseStat(StatsEnum.CHARISMA, 1);
        global.ui.showFullscreenPopup(buildPopupContents());
        return true;
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
