/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsHideBush(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";
    var thirdId = arguments.callee.name + "ButtonThree";

    var firstChoice = new ForestWoodsHideSurrender(ctrl);
    var secondChoice = new ForestWoodsRun(ctrl);
    var thirdChoice = new ForestWoodsHideStick(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The simplest option would be to hide in a bush.
                            Easy to get into, easy to get out of.
                            If you get spotted while hiding way up in a tree, you won't have anywhere to run.
                            You'll be trapped, stuck ten feet up without any way out.
                            If your pursuers somehow manage to [i]find[/i] you hiding in a bush, then you can simply [b]bolt[/b] out of it and run away.
                            A win-win situation, really.
                        [/p]
                        [p]
                            You pick a nice, dense shrub and quickly stride into it, your entire body,
                            from the claws of your feet to the scaly tip of your head covered and camouflaged with foliage without even [b]needing[/b] to duck down.
                            The perfect hiding spot!
                            They'll never find you here.
                            Not unless they have some kind of...
                            [b]Oh no![/b]
                        [/p]
                        [p]
                            You [b]completely[/b] forgot about the feral dog they had with them!
                            It'll sniff you out for sure!
                            You [i]should[/i] have gone for the tree, but it's [b]far[/b] too late to change places now.
                            You already can see your pursuers approaching in the distance, feral canine leading the party, barks echoing throughout the entire forest.
                        [/p]
                        [p]
                            You panic.
                            A million thoughts race through your mind.
                            You can't stay here.
                            Not without a way to distract the dog.
                            Even then, it'll be risky.
                            It might be better to just [i]come clean[/i].
                            But then again, you [b]really[/b] need this gold.
                            Maybe you can make a run for it?
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = ctrl.bush.has() ? "disabled" : "";
        var isSelected = ctrl.bush.get() === ForestWoodsHideBushChoice.SURRENDER;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Surrender</button>`;

        var tooltip = global.parser.parse(`The jig is up. If you surrender, they might spare your life.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = ctrl.bush.has() ? "disabled" : "";
        var isSelected = ctrl.bush.get() === ForestWoodsHideBushChoice.RUN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Run</button>`;

        var tooltip = global.parser.parse(`They haven't caught you [i]yet[/i]. Leg it!`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThirdChoice() {
        var stick = ctrl.intro.getItemChoice() === ItemEnum.BRANCH;
        var disabled = ctrl.bush.has() || !stick ? "disabled" : "";
        var isSelected = ctrl.bush.get() === ForestWoodsHideBushChoice.STICK;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${thirdId}" ${disabled}>Throw stick</button>`;

        var tooltip = global.parser.parse(`If you throw your branch, that might distract the dog for long enough for you to escape.`);
        if (!stick) {
            tooltip = global.parser.parse(`If only you had one.`);
        }
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 220px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You:</div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildThirdChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId), $("#" + thirdId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bush.set(ForestWoodsHideBushChoice.SURRENDER);
            loadNextPart(firstChoice);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bush.set(ForestWoodsHideBushChoice.RUN);
            loadNextPart(secondChoice);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerThirdListener() {
        $("#" + thirdId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.bush.set(ForestWoodsHideBushChoice.STICK);
            loadNextPart(thirdChoice);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.hide.get() !== ForestWoodsHideChoice.BUSH) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.bush.change();
        part += buildChoice();
        part += `</div>`;
        part += firstChoice.build();
        part += secondChoice.build();
        part += thirdChoice.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.hide.get() !== ForestWoodsHideChoice.BUSH) {
            return;
        }

        firstChoice.registerListeners();
        secondChoice.registerListeners();
        thirdChoice.registerListeners();

        if (ctrl.bush.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
        registerThirdListener();
    };
}

var ForestWoodsHideBushChoice = {
    SURRENDER: 1,
    RUN: 2,
    STICK: 3
};
