/**
 * Arrival section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseWrestleSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;
    
    var chokeId = arguments.callee.name + "ButtonOne";
    var rapeId = arguments.callee.name + "ButtonTwo";

    var toChoke = new FarmerHouseWrestleChoke(ctrl);
    var toRape = new FarmerHouseWrestleRape(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You have to stop her from screaming for help.
                            The only way you can do that is by covering her mouth, which you can't reach.
                            You're going to have to [b]bring her down[/b] to your level somehow.
                            And that means you need to get [i]physical[/i].
                        [/p]
                        [p]
                            You wildly charge the scared housewife, roughly grabbing her by the hips, the very centre of her mass, in an attempt to throw her to the floor.
                            She harshly [b]slaps[/b] you in the face, but that doesn't prevent you from tugging her away from the kitchen counter,
                            and [b]hurling[/b] her to the ground, the human falling face-first on top of the rotten, wooden floor with a loud thud, and a soft pained grunt.
                        [/p]
                        ${global.ui.condSucc(`Strength greater than 5`)}
                        [p]
                            You leap on top of the woman, [b]slamming[/b] your body into hers.
                            While you don't weigh that much, your move still suffices to knock the air out of the housewife's lungs,
                            preventing her from screaming for just long enough for you take hold of both of her arms, restraining them behind her back.
                            The moment she recovers her breath enough to attempt to shriek, you firmly plant the palm of your free hand on the lower half of her face,
                            her shout muffled to the point of inaudibility.
                        [/p]
                        [p]
                            The feisty human tries, but fails, to bite your palm.
                            She attempts to free her arms, to no avail.
                            She may be larger than you, but she [i]isn't[/i] by any means [b]stronger[/b].
                            Giving up on overpowering you, the woman begins to wildly kick her legs and wriggle her body around, striving to throw you off of her.
                        [/p]
                        [p]
                            Growing tired of her resistance, you cruelly press your knee into her back,
                            causing her more than a little discomfort while pinning her to the floor.
                            Still, she does not relent, both her legs still wildly flailing about.
                            Stupid human just doesn't know when to give up.
                            You press your sharp claws against her cheeks, digging into her soft and tender flesh without drawing blood,
                            while at the same time painfully twisting one of her arms.
                        [/p]
                        [p]
                            Finally, her protests die down, at least to the point where you don't have to actively [b]struggle[/b] to keep her in place.
                            While the housewife clearly hasn't [i]given up[/i] yet, you've scared her into calming down, for now.
                            Still, you doubt she'll remain [i]pacified[/i] for long.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildChokeChoice() {
        var disabled = ctrl.wrestle.has() ? "disabled" : "";
        var isSelected = ctrl.wrestle.get() === FarmerHouseWrestleSuccessChoice.CHOKE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${chokeId}" ${disabled}>Choke her</button>`;

        var tooltip = global.parser.parse(`Knock her out so you can loot in peace.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildRapeChoice() {
        var disabled = ctrl.wrestle.has() ? "disabled" : "";
        var isSelected = ctrl.wrestle.get() === FarmerHouseWrestleSuccessChoice.RAPE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${rapeId}" ${disabled}>Rape her</button>`;

        var tooltip = global.parser.parse(`You've got her pinned down. Time to have some [i]fun[/i] with the human.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildChokeChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildRapeChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + chokeId), $("#" + rapeId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerChokeListener() {
        $("#" + chokeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.wrestle.set(FarmerHouseWrestleSuccessChoice.CHOKE);
            loadNextPart(toChoke);
        });
    }
    
    /**
     * Adds a listener to the button.
     */
    function registerRapeListener() {
        $("#" + rapeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.wrestle.set(FarmerHouseWrestleSuccessChoice.RAPE);
            loadNextPart(toRape);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.wrestle.change();
        part += buildChoice();
        part += `</div>`;
        part += toChoke.build();
        part += toRape.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        toChoke.registerListeners();
        toRape.registerListeners();

        if (ctrl.wrestle.has()) {
            return;
        }

        registerChokeListener();
        registerRapeListener();
    };
}

var FarmerHouseWrestleSuccessChoice = {
    CHOKE: 1,
    RAPE: 2
};

