/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseCabinet(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var drawerId = arguments.callee.name + "ButtonOne";
    var pryId = arguments.callee.name + "ButtonTwo";
    var topShelfId = arguments.callee.name + "ButtonThree";

    var toDrawer = new FarmerHouseDrawer(ctrl);
    var toPry = new FarmerHousePry(ctrl);
    var toTopShelf = new FarmerHouseTopShelf(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The cupboard is your best bet.
                            You doubt the woman'll be returning to the kitchen any time soon,
                            and even if she does, she might just [i]overlook[/i] you like she did the first time.
                            Besides, what better place to store a bunch of valuables than a sole piece of furniture at the very rear end of the house?
                        [/p]
                        [p]
                            You step out from behind your cover, and turn to face the cabinet properly.
                            It is a decently-sized, rickety construct, parts of which are rotten to the point where you could probably punch right through the wood.
                            The bottom half consists of a single, rather large compartiment, which is topped off by a drawer.
                            Further upwards are a bunch of empty shelves, but you can see a crate of some sort on the very topmost one, far out of your reach.
                            You try to open the compartiment instead, but it is jammed shut.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildDrawerChoice() {
        var disabled = ctrl.cabinet.has() ? "disabled" : "";
        var isSelected = ctrl.cabinet.get() === FarmerHouseCabinetChoice.DRAWER;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${drawerId}" ${disabled} style="width:190px;">Check the drawer</button>`;

        var tooltip = global.parser.parse(`The easiest part to get to. Bound to contain some goodies.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildPryChoice() {
        var strongEnough = ctrl.misc.strength() >= 6;
        var disabled = ctrl.cabinet.has() || !strongEnough ? "disabled" : "";
        var isSelected = ctrl.cabinet.get() === FarmerHouseCabinetChoice.PRY;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${pryId}" ${disabled} style="width:190px;">Force it open</button>`;

        var tooltip = global.parser.parse(`Requires [b]6 strength[/b].`);
        if (strongEnough) {
            tooltip = global.parser.parse(`The small wooden door is jammed shut, but you can pry it open with some elbow grease.`);
        }

        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildTopShelfChoice() {
        var statCheck = ctrl.misc.agility() >= 6;
        var disabled = ctrl.cabinet.has() || !statCheck ? "disabled" : "";
        var isSelected = ctrl.cabinet.get() === FarmerHouseCabinetChoice.TOPSHELF;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${topShelfId}" ${disabled} style="width:190px;">Climb up</button>`;

        var tooltip = global.parser.parse(`Requires [b]6 agility[/b].`);
        if (statCheck) {
            tooltip = global.parser.parse(`Climb on top of the cabinet to reach the top shelf.`);
        }

        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 200px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildDrawerChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildPryChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildTopShelfChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + drawerId), $("#" + pryId), $("#" + topShelfId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerDrawerListener() {
        $("#" + drawerId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.cabinet.set(FarmerHouseCabinetChoice.DRAWER);
            loadNextPart(toDrawer);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerPryListener() {
        $("#" + pryId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.cabinet.set(FarmerHouseCabinetChoice.PRY);
            loadNextPart(toPry);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerTopShelfListener() {
        $("#" + topShelfId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.cabinet.set(FarmerHouseCabinetChoice.TOPSHELF);
            loadNextPart(toTopShelf);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.inside.get() !== FarmerHouseInsideChoice.CABINET) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toDrawer.build();
        part += toPry.build();
        part += toTopShelf.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.inside.get() !== FarmerHouseInsideChoice.CABINET) {
            return;
        }

        toDrawer.registerListeners();
        toPry.registerListeners();
        toTopShelf.registerListeners();

        if (ctrl.cabinet.has()) {
            return;
        }

        registerDrawerListener();
        registerPryListener();
        registerTopShelfListener();
    };
}

var FarmerHouseCabinetChoice = {
    DRAWER: 1,
    PRY: 2,
    TOPSHELF: 3
};

