/**
 * Steal section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseTopShelf(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var nextId = arguments.callee.name + "ButtonOne";
    var next = new FarmerHouseCabinetRun(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The box on top of the cabinet has piqued your attention.
                            You can't quite see what it contains,
                            but you're pretty certain a poor family like this would have scrapped the crate for firewood long ago if it weren't something [i]good[/i].
                            Why put it all the way [i]up there[/i], though?
                            These humans have to make [b]everything[/b] harder than it needs to be, don't they?
                        [/p]
                        [p]
                            With a soft sigh and a rolling of your eyes, you hoist yourself onto the bottom half of the cupboard.
                            The wooden piece of furniture creaks menacingly as you place your entire weight upon it,
                            almost as though it's [b]threatening[/b] to crack should you proceed to scale its rotten shelves.
                            Even standing upright on the lower half, you still can't reach the top.
                        [/p]
                        [p]
                            You consider your options.
                            You [i]could[/i] jump up and try to snag the crate, but that would probably cause the entire cabinet to break upon your landing.
                            Besides the noise attracting unwanted attention, you might fall,
                            and if there's something fragile in the box, all of your efforts may have been for nothing.
                        [/p]
                        [p]
                            Jumping ruled out, you begin to test the individual [i]racks[/i].
                            Most of them are rotten through and through, a few barely even withstanding your gentle, testing pats.
                            Only [b]one[/b] of the planks seems stable enough to hold any sort of weight, at least for a little while.
                            It's the bottom-most one, a few inches above the surface you're standing on,
                            perfect for giving you a small boost, which may be just enough for you to reach the top.
                        [/p]
                        [p]
                            You gingerly place one of your feet atop of the non-rotten plank, testing its limits.
                            You aren't too sure about this, but it's the only way you're going to get to the crate that [i]doesn't[/i] involve making a ruckus.
                            You decide to go for it.
                            Hoping for the best, you lift yourself upwards, hoisting your entire body up onto the tips of your toes.
                            The box coming into reach, you grab onto it, slide it off the top of the cabinet, and in a single, smooth motion,
                            you drop back down onto the lower half of the cupboard, your descent aided by the sheer [b]weight[/b] of the crate.
                        [/p]
                        [p]
                            The wooden piece of furniture creaks even loader than before, as though it's on the [b]verge[/b] of breaking.
                            You decide to hop off of it [i]before[/i] you ruin your slick move.
                            You quietly hop to the ground.
                            It is only when you land for a second time, that the heaviness of the open-topped crate begins to burden you.
                            You quickly set it down on the floor, careful not to break any of the glass bottles contained within.
                        [/p]
                        [p]
                            You let out a soft, relieved sigh.
                            Those were a couple of intense moments, but all things considered, you made it out just fine.
                            Time to inspect the loot.
                            You take a bottle out of the box.
                            Empty.
                            No worries, you probably just picked the wrong one to begin with.
                            You pull out another.
                            Also empty?!
                            Did you just risk [b]all of that[/b] for a crate filled with [b]empty bottles[/b]?!
                        [/p]
                        [p]
                            You frantically remove container after container from the box, the most filled one thus far containing naught but a few [b]droplets[/b].
                            This can't be happening.
                            Why would they put [b]empty bottles[/b] on top of the darned cupboard?!
                            Your hope of scoring a good haul having all but sunk, you pull out the very last of the glass flasks.
                            You can immediately feel that it's different.
                            Heavier.
                            A smile forms on your face.
                            It's full.
                        [/p]
                        [p]
                            "${global.kobold.inventory.createItemWithTooltip(new CouragePotion(), true)}", it says on the label.
                            You'll have to try it out later.
                            Or you could sell it at Varanar.
                            Either way, now is not the time to think about what you're going to do with the bottle.
                            You pocket it, and silently slip through the back door from which you came.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.cabinetSteal.continued() ? "disabled" : "";
        var isSelected = ctrl.cabinetSteal.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${nextId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + nextId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + nextId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.cabinetSteal.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.cabinet.get() !== FarmerHouseCabinetChoice.TOPSHELF) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.cabinetSteal.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.cabinet.get() !== FarmerHouseCabinetChoice.TOPSHELF) {
            return;
        }

        next.registerListeners();

        if (ctrl.cabinetSteal.continued()) {
            return;
        }

        registerNextListener();
    };
}
