/**
 * Arrival section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoRunIn(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var ignoreId = arguments.callee.name + "ButtonOne";
    var fleeId = arguments.callee.name + "ButtonTwo";

    var toIgnore = new NightTwoConfront(ctrl);
    var toFlee = new NightTwoFlee(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After resting your feet for a while, you decide it's best to get a lay of the land before catching some shut-eye.
                            The night is still young, and you know pretty much nothing of the cityscape outside of the grand avenue.
                            Actually, you [i]do[/i] know how to make your way to the hideout of the Three-Tailed Rat Clan,
                            nested deep within the kobold district of Varanar,
                            but only because you [i]memorized[/i] the route between there and the eastern city gate.
                            Hoping to get a clearer picture of what road leads where, you pick a street at random,
                            and begin your journey of exploration throughout the city.
                        [/p]
                        [p]
                            You wander through the mercantile district and the residential area,
                            you pause briefly to inspect the magnificent architecture of the local church,
                            you walk alongside the river that splits the capital in two,
                            and you wisely avoid the kobold district at this time of night.
                            Less than two hours after you left the town square,
                            you manage to form a pretty decent idea on how to get around Varanar.
                        [/p]
                        [p]
                            Still, there's plenty more avenues left to explore, and you don't feel like going to bed quite yet,
                            too enthralled by all the sights to see to stop now.
                            Ultimately, after another few hours of discovery and mental mapmaking, you find yourself in a less [i]savory[/i] part of town.
                            You aren't sure whether you should nickname this area the [i]brothel district[/i] or the [i]tavern zone[/i].
                            Houses in this neighbourhood are as poorly built and maintained as they are in the kobold quarter,
                            although they are, admittedly, a lot [i]bigger[/i].
                        [/p]
                        [p]
                            While most of the city's streets are well-patrolled and well-lit, this section seems mostly exempt from sentries and guards.
                            Or maybe it's just getting so late that most of them have already gone to sleep.
                            You, too, are starting to get sleepy.
                            You begin to make your way back to the city square in hopes of finding an inn,
                            a bale of hay or at least an alleyway that [i]doesn't[/i] smell like someone died in it.
                        [/p]
                        [p]
                            As you turn a corner, you notice a small group of burly human males headed your way.
                            They seem drunk and unsavory, probably returning home after a night full of beer and wenches.
                            One of them crudely points his finger your way while loudly chattering to his friends.
                            You can't quite understand them, but whatever he said must have been funny.
                            The group bursts out into laughter.
                            Their eyes become fixated on you.
                            Somehow, you don't feel very safe anymore.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildIgnoreChoice() {
        var disabled = ctrl.runin.has() ? "disabled" : "";
        var isSelected = ctrl.runin.get() === NightTwoRunInChoice.IGNORE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${ignoreId}" ${disabled}>Ignore them</button>`;

        var tooltip = global.parser.parse(`Walk past the group. Maybe they'll leave you alone. `);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFleeChoice() {
        var disabled = ctrl.runin.has() ? "disabled" : "";
        var isSelected = ctrl.runin.get() === NightTwoRunInChoice.FLEE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${fleeId}" ${disabled}>Flee</button>`;

        var tooltip = global.parser.parse(`Walk the other way. Keep a steady pace to stay ahead of them.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildIgnoreChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildFleeChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + ignoreId), $("#" + fleeId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerIgnoreListener() {
        $("#" + ignoreId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.runin.set(NightTwoRunInChoice.IGNORE);
            loadNextPart(toIgnore);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFleeListener() {
        $("#" + fleeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.runin.set(NightTwoRunInChoice.FLEE);
            loadNextPart(toFlee);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.stage.continued()) {
            return "";
        }

        ctrl.bgm.loop();
        global.kobold.inventory.exitSafeZone();
        global.ui.imageBackground.hide();
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toIgnore.build();
        part += toFlee.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.stage.continued()) {
            return;
        }

        toIgnore.registerListeners();
        toFlee.registerListeners();

        if (ctrl.runin.has()) {
            return;
        }

        registerIgnoreListener();
        registerFleeListener();
    };
}

var NightTwoRunInChoice = {
    IGNORE: 1,
    FLEE: 2
};

