/**
 * Flee section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoAlleyRunSuccess(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NightTwoAlleyRunSuccessContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You envision your way up along the side of the wall on the far end of the alley.
                            First you'll run towards it, then you intend to [b]jump[/b], and using the momentum gained from your dash,
                            you'll kick yourself off of one of the walls, ending up high enough to latch on to the top of the brick wall.
                            From then, it's a matter of pulling yourself up, and after that you'll be in the clear.
                        [/p]
                        [p]
                            With your plan visualized, it's time to put it into motion.
                            You [b]sprint[/b] forwards, accelerating at a rapid pace.
                            Running past the last of the barrels, you [b]leap[/b] from the ground as high up as you can.
                            Mid-air, you press your right foot against the alley-wall, and expertly push yourself up even higher,
                            converting horizontal momentum into vertical lift.
                        [/p]
                        [p]
                            Exactly as planned, you narrowly reach the height required to grab the top of the wall,
                            your claws digging in to the mortar in between the bricks ever so slightly.
                            Using all of your strength, you deftly begin to pull yourself upwards,
                            lifting your light frame up onto the barrier, coming to a seated rest on top of it.
                        [/p]
                        ${global.ui.condSucc(`Strength and agility greater than 5`)}
                        [p]
                            Just in time, or so it seems.
                            One of the men chasing you wanders into the alleyway.
                            Whether he didn't see you perched up high, or if he simply had no intention of calling for his friends, you will never know.
                            You lower yourself on the opposite end of the brick wall, and with a feline-resembling grace, you hop down to the ground once more.
                            With the group shaken off, for now, at least, you quickly and quietly make your way to [i]less hostile[/i] parts of Varanar.
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.alleyRunSuccess.continued() ? "disabled" : "";
        var isSelected = ctrl.alleyRunSuccess.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.alleyRunSuccess.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.alleyRunSuccess.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        next.registerListeners();

        if (ctrl.alleyRunSuccess.continued()) {
            return;
        }

        registerNextListener();
    };
}
