

// SCENE SekiWorkshop

// scenes\HamletDay2\SekiWorkshop\center\SekiWorkshopCenter.js

/**
 * Buy section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopCenter(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var breedingId = "centerBreedingButton";
    var farmHomeId = "centerFarmHomeButton";
    var wellId = "centerWellButton";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Disheartened, you leave Seki's store and walk towards the small well at the very center of the hamlet.
                            Leaning against it, you take a moment to collect your thoughts.
                            ${global.kobold.history.shared.enslavement.noonTwo.boughtBySeki ? `The stage you were put on display on has already been torn down.` : ``}
                        [/p]
                        [p]
                            Seki is a brilliant alchemist.
                            Perhaps even one of the best ones to have ever lived.
                            But to you, he's more than that.
                            He's your kind of, not really, somewhat of a [i]father figure[/i].
                            You wouldn't know what you'd do if he was gone.
                            You're not ready to lose him.
                        [/p]
                        [p]
                            You can't.
                            You [b]won't[/b].
                            You're [b]not[/b] going to.
                            Even if it means you need to travel through [b]hell[/b] itself to drag his old,
                            feathery ass out of the afterlife,
                            you are [b]not[/b] losing Seki, [b]no matter what[/b].
                            ${global.kobold.history.shared.enslavement.noonTwo.boughtBySeki ? `He saved you, now you're going to save him.` : ``}
                            If you need to punch the Grim Reaper himself in the face, then so be it.
                            That bony bastard is [b]not[/b] taking your feathery father from you.
                            [b]Over your dead body.[/b]
                        [/p]
                        [p]
                            You kick a small rock in frustration.
                            It skips along the dirt for a few feet, then comes to rest.
                            You wipe a few tears from your eyes.
                            Luckily, nobody is around to see you.
                            This place looks deserted.
                            Everyone is probably indoors or out working the field or in Varanar or wherever.
                        [/p]
                        [p]
                            You can't sit around here moping all day long.
                            Well, you could, but Seki wouldn't want that.
                            He'd probably chase you from the hamlet himself if he could run for more than five feet without being out of breath.
                            You're going to miss him.
                            A lot.
                            You almost burst into tears.
                            It's just [i]not fair[/i].
                            ${global.kobold.history.shared.enslavement.noonTwo.boughtBySeki ? `First you become a [b]slave[/b], now this.` : ``}
                        [/p]
                        [p]
                            Taking a look around, you spot three places of interest that might prove worthy of exploration.
                            The breeding farm across the road from Seki's workshop is an obvious choice.
                            Both the fancy-looking house as well as the attached barn could be full of stuff for you to steal.
                            You don't know [i]who[/i] owns that place, though.
                            You've heard Seki talk about some woman constantly buying up all of his ${global.kobold.inventory.createItemWithTooltip(new FemPlus())}s.
                            Could be related, but you don't really know for certain.
                        [/p]
                        [p]
                            Alternatively, you could break into a random farmer's house.
                            Should be empty, save for a stay-at-home spouse or perhaps some offspring.
                            ${global.kobold.history.shared.enslavement.noonTwo.boughtBySeki ? `Farmers have returned to their fields after the auction.` : ``}
                            There probably won't be [i]that much[/i] to steal, but it's a safer bet than the breeding farm.
                        [/p]
                        [p]
                            The final point of interest is the well you're leaning against.
                            It might prove valuable to give it a more [i]thorough[/i] inspection.
                            People around these rural parts are pretty superstitious.
                            You wouldn't be surprised if they hurled an entire fortune worth of individual coins down the waterhole,
                            praying for good luck or wishing for a better life.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${breedingId}" ${disabled ? "disabled" : ""} style="margin: auto; float: left;">`;
        choice += `Breeding farm &gt;&gt`;
        choice += `</button>`;
        choice += `<button class="button bigbutton continuebutton" id="${farmHomeId}" ${disabled ? "disabled" : ""} style="margin: auto; float: right;">`;
        choice += `Farmer's home &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        choice += `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${wellId}" ${disabled ? "disabled" : ""} style="margin: auto;">`;
        choice += `Well investigation &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + breedingId), $("#" + farmHomeId), $("#" + wellId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerBreedingListener() {
        $("#" + breedingId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.breedingSceneName, ctrl.folderName);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerFarmHouseListener() {
        $("#" + farmHomeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.farmHomeSceneName, ctrl.folderName);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerWellListener() {
        $("#" + wellId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.wellSceneName, ctrl.folderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiCenter";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.free.continued() && !ctrl.buyContinue.continued()) {
            return "";
        }
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.free.continued() && !ctrl.buyContinue.continued()) {
            return;
        }

        if (ctrl.continued()) {
            return;
        }

        registerBreedingListener();
        registerFarmHouseListener();
        registerWellListener();
    };
}

// END scenes\HamletDay2\SekiWorkshop\center\SekiWorkshopCenter.js

// scenes\HamletDay2\SekiWorkshop\free\SekiWorkshopFree.js

/**
 * Free section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopFree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "freeContinueButton";

    var next = new SekiWorkshopCenter(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After about a minute of waiting, you begin to get a bit impatient.
                            You ring the bell a few more times, until you finally get a response in the form of a raspy,
                            bass shout coming from the darkness on the far end of the counter:
                            "[color=brown]Hold your horses!
                            Settle down!
                            I'm on my way!
                            Can't an old man get a minute to finish grinding his herbs?!
                            You youngsters are always so [b]restive[/b]![/color]"
                        [/p]
                        [p]
                            Loudly grumbling, the elderly owl emerges from the shadows, stepping into the dim candlelight,
                            which illuminates his once-brown, but now pale grey feathers.
                            Readjusting the heavy, thick spectacles atop his beak,
                            the angry frown on the bird's face changes to a happy,
                            heartfelt smile as he realizes the tiny little thing that interrupted his machinations was none other but, well, [b]you[/b].
                        [/p]
                        [p]
                            "[color=brown]Ahhh!
                            My favorite customer!
                            Uhhh...[/color]"
                            The avian brings his feathery hand towards his forehead, wiping his brow as he visibly tries his very hardest to recall your name.
                            You know he didn't forget you.
                            His old mind just can't remember things quite as well as it used to.
                            You understand.
                            Returning a smile, you coyly hint that your name is ${ctrl.name()}.
                        [/p]
                        [p]
                            "[color=brown]Yes, yes!
                            ${ctrl.name()}!
                            I knew that!
                            I was just [b]catching my breath[/b] from walking all the way over here.[/color]"
                            Silly old geezer.
                            "[color=brown]Let me take a good look at you.[/color]"
                            He continues, leaning forwards over the counter, gazing down at you with his large owl eyes.
                        [/p]
                        `;
        if (ctrl.health() < 80) {
            toReturn += `[p] 
                            "[color=brown]You look like you've seen better days!
                            Who'd you get in a tussle with this time, eh?
                            It's probably best if you [b]don't[/b] tell me.
                            If they can beat up a fierce youngling like yourself, an old geezer like me wouldn't stand much of a chance.
                            Twenty years ago, I'd have shown those ruffians what-for, let me tell you![/color]"
                        [/p]`;
        } else {
            toReturn += `[p] 
                            "[color=brown]You look fit as ever!
                            Taking good care of yourself, eh?
                            'Atta ${ctrl.gender() === GenderEnum.MALE ? "boy" : "girl"}.
                            It'd pain an old man's heart to see a pretty little snout like yours get hurt.
                            Do me a favor and keep yourself out of harm's way, won't you?
                            Not for your sake, but for mine.[/color]"
                        [/p]`;
        }

        toReturn += `   [p] 
                            Then, Seki begins to reminisce, as he always does when you come to visit him.
                            "[color=brown]When I was your age, I was out explorin' the world.
                            I fought trolls, I climbed mountains, I even found what I believed to be the fabled well of youth![/color]"
                            A small pause.
                            A smirk forms on Seki's face.
                            He winks at you.
                            "[color=brown]Turns out it was just an ordinary river spring, but you probably could have guessed that by taking a look at me, eh?[/color]"
                        [/p]
                        [p]
                            The old man bursts into laughter, which quickly devolves into a coughing fit.
                            The smile is wiped off his face.
                            Hacking and wheezing, he spits a distinctly red-colored wad of phlegm from his beak onto the ground.
                            You fear for his well-being, the bird visibly hurting, but the moment he catches his breath,
                            he turns towards you, smile plastered across his face once more.
                            You don't know whether or not he's [i]acting[/i] tough.
                        [/p]
                        [p]
                            "[color=brown]Don't worry about me.[/color]"
                            Seki says, as if that's supposed to comfort you.
                            "[color=brown]Just a common cold.
                            Nothin' more.[/color]"
                            You mention that he has the [b]cure[/b] for that.
                            He once made you feel [b]much[/b] better with just a small potion.
                            The owl looks away.
                            All playfulness vanishes from his face, a disconcerting seriousness taking its place.
                            Tears form at the corners of his eyes.
                            He swallows deeply.
                            "[color=brown]It's not the kind of cold that can be cured.[/color]"
                        [/p]
                        [p]
                            The old man pokes a feathery finger underneath his glasses to wipe his eyes, in order to pretend he wasn't crying.
                            He turns towards you once more, a shaky, obviously faked grin on his face.
                            With the same finger he used to collect his tears, he points towards the empty coinpurse hanging from your neck.
                            "[color=brown]Well, you won't be buyin' much with that.
                            And you know the rule: no buyin' means no sellin'.[/color]"
                        [/p]
                        [p]
                            You're still stuck trying to process what he just said.
                            Is Seki going to...die?
                            The old man notices your confusion, and in an attempt to break the grim mood that has fallen upon the conversation,
                            he opens up a drawer, and fetches a familiarly shaped piece of metal.
                        [/p]
                        [p]
                            "[color=brown]Can't send you off without a means to fill up that empty pouch of yours, now can I?[/color]"
                            He asks, rhetorically, whilst handing you a single ${global.kobold.inventory.createItemWithTooltip(new Lockpick())}.
                            "[color=brown]Don't go using it all in one place now, eh?[/color]"
                            The bird jokes, seemingly [i]wanting[/i] to laugh, but not wanting to cough up another piece of his lungs.
                        [/p]
                        [p]
                            "[color=brown]Anyway, off you go.[/color]"
                            He continues, turning around and beginning to walk away at a slow pace.
                            "[color=brown]I'll be in the city for the next few days, but be sure to stop by here sometime before next week, you hear?
                            I want to see my little [b]${ctrl.gender() === GenderEnum.MALE ? "man" : "woman"}[/b] one last time before...[/color]"
                            Stopping mid-sentence, Seki lets out a loud, depressed sigh before silently disappearing into the darkness,
                            either to tend to his wounds, or to lament in solitude.
                        [/p]
                        [p]
                            Heartbroken, you hang your head and barely refrain from crying as you walk out of the old owl's shop.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the alternate content of this section.
     * @returns {string} The content.
     */
    function buildAltContent() {
        var toReturn = `[p]
                            Suddenly, Seki bursts into a coughing fit.
                            The heart-warming smile is wiped off his face.
                            Hacking and wheezing, he spits a distinctly red-colored wad of phlegm from his beak onto the ground.
                            You fear for his well-being, the bird visibly hurting, but the moment he catches his breath,
                            and notices you staring, a small smile creeps onto his face once more.
                            You don't know whether or not he's [i]acting[/i] tough.
                        [/p]
                        [p]
                            "[color=brown]Don't worry about me.[/color]"
                            The old bird says, as if that's supposed to comfort you.
                            "[color=brown]Just a common cold.
                            Nothin' more.[/color]"
                            You mention that he has the [b]cure[/b] for that.
                            He once made you feel [b]much[/b] better with just a small potion.
                            The owl looks away.
                            All playfulness vanishes from his face, a disconcerting seriousness taking its place.
                            Tears form at the corners of his eyes.
                            He swallows deeply.
                            "[color=brown]It's not the kind of cold that can be cured.[/color]"
                        [/p]
                        [p]
                            The avian pokes a feathery finger underneath his glasses to wipe his eyes, in order to pretend he wasn't crying.
                            He gives you a shaky, obviously faked grin.
                            "[color=brown]You worry about yourself first and foremost.
                            I...might not be around to save you next time.[/color]"
                            You're still stuck trying to process what he just said.
                            Is Seki going to...die?
                            The old man notices your confusion, and in an attempt to break the grim mood that has fallen upon the conversation,
                            he quickly changes the topic.
                        [/p]
                        [p]
                            "[color=brown]Anyway, you caught me right as I was about to head for Varanar.[/color]"
                            He begins to walk away to the back of his store, at a slow pace.
                            You're not sure whether you should follow him or not.
                            "[color=brown]I'll be in the city for the next few days, but be sure to stop by here sometime before next week, you hear?
                            I want to see my little [b]${ctrl.gender() === GenderEnum.MALE ? "man" : "woman"}[/b] one last time before...[/color]"
                            Stopping mid-sentence, Seki lets out a loud, depressed sigh before silently disappearing into the darkness,
                            either to tend to his wounds, to lament in solitude, or to leave via the back door.
                        [/p]
                        [p]
                            Heartbroken, you hang your head and barely refrain from bursting into tears once more as you walk out of the old owl's shop.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.free.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.free.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiFree";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.entrance.continued() || ctrl.gold() >= ctrl.minBuyGold) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (global.kobold.history.shared.enslavement.noonTwo.boughtBySeki) {
            part += buildAltContent();
            part += ctrl.free.altChange();
        } else {
            part += buildContent();
            part += ctrl.free.change();
        }
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.entrance.continued() || ctrl.gold() >= ctrl.minBuyGold) {
            return;
        }

        next.registerListeners();

        if (ctrl.free.continued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\HamletDay2\SekiWorkshop\free\SekiWorkshopFree.js

// scenes\HamletDay2\SekiWorkshop\shop\SekiWorkshopBuy.js

/**
 * Buy section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopBuy(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "buyContinueButton";
    var next = new SekiWorkshopBuyContinue(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After about a minute of waiting, you begin to get a bit impatient.
                            You ring the bell a few more times, until you finally get a response in the form of a raspy,
                            bass shout coming from the darkness on the far end of the counter:
                            "[color=brown]Hold your horses!
                            Settle down!
                            I'm on my way!
                            Can't an old man get a minute to finish grinding his herbs?!
                            You youngsters are always so [b]restive[/b]![/color]"
                        [/p]
                        [p]
                            Loudly grumbling, the elderly owl emerges from the shadows, stepping into the dim candlelight,
                            which illuminates his once-brown, but now pale grey feathers.
                            Readjusting the heavy, thick spectacles atop his beak,
                            the angry frown on the bird's face changes to a happy,
                            heartfelt smile as he realizes the tiny little thing that interrupted his machinations was none other but, well, [b]you[/b].
                        [/p]
                        [p]
                            "[color=brown]Ahhh!
                            My favorite customer!
                            Uhhh...[/color]"
                            The avian brings his feathery hand towards his forehead, wiping his brow as he visibly tries his very hardest to recall your name.
                            You know he didn't forget you.
                            His old mind just can't remember things quite as well as it used to.
                            You understand.
                            Returning a smile, you coyly hint that your name is ${ctrl.name()}.
                        [/p]
                        [p]
                            "[color=brown]Yes, yes!
                            ${ctrl.name()}!
                            I knew that!
                            I was just [b]catching my breath[/b] from walking all the way over here.[/color]"
                            Silly old geezer.
                            "[color=brown]Let me take a good look at you.[/color]"
                            He continues, leaning forwards over the counter, gazing down at you with his large owl eyes.
                        [/p]
                        `;
        if (ctrl.health() < 80) {
            toReturn += `[p] 
                            "[color=brown]You look like you've seen better days!
                            Who'd you get in a tussle with this time, eh?
                            It's probably best if you [b]don't[/b] tell me.
                            If they can beat up a fierce youngling like yourself, an old geezer like me wouldn't stand much of a chance.
                            Twenty years ago, I'd have shown those ruffians what-for, let me tell you![/color]"
                        [/p]`;
        } else {
            toReturn += `[p] 
                            "[color=brown]You look fit as ever!
                            Taking good care of yourself, eh?
                            'Atta ${ctrl.gender() === GenderEnum.MALE ? "boy" : "girl"}.
                            It'd pain an old man's heart to see a pretty little snout like yours get hurt.
                            Do me a favor and keep yourself out of harm's way, won't you?
                            Not for your sake, but for mine.[/color]"
                        [/p]`;
        }

        toReturn += `   [p]
                            Noticing your well-filled coin purse, the bird's smirk deepens.
                            "[color=brown]Come across some gold, now have you?
                            While I sometimes forget, I [i]am[/i] running a store here.
                            Feel free to browse, just don't sample anything without asking me first.[/color]"
                        [/p]
                        [p][sneak]
                            You are in a safe zone.
                            You can use items from your inventory here.
                            You are in a store.
                            You can sell items from your inventory here.
                            You may buy items from the list below.
                            Keep in mind that all purchases are final.
                            Worn equipment can not be sold.
                            Buying equipment will discard your previous attire.
                        [/sneak][/p]`;
        toReturn += ctrl.buy.getGenerator().build();
        toReturn += `[p][sneak]
                            Remember that you can not drink potions or eat food outside of safe zones.
                            You might want to use some of the items you've purchased before continuing.
                        [/sneak][/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.buy.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.buy.continue();
            ctrl.buy.getGenerator().disable();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiBuy";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.entrance.continued() || ctrl.gold() < ctrl.minBuyGold) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.entrance.continued() || ctrl.gold() < ctrl.minBuyGold) {
            return;
        }

        next.registerListeners();

        if (ctrl.buy.continued()) {
            return;
        }

        registerContinueListener();
        ctrl.buy.getGenerator().registerListeners();
    };
}

// END scenes\HamletDay2\SekiWorkshop\shop\SekiWorkshopBuy.js

// scenes\HamletDay2\SekiWorkshop\shop\SekiWorkshopBuyContinue.js

/**
 * Buy section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopBuyContinue(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "buyContinueReduxButton";
    var next = new SekiWorkshopCenter(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p] 
                            With your business concluded, Seki begins to reminisce, as he always does when you come to visit him.
                            "[color=brown]When I was your age, I was out explorin' the world.
                            I fought trolls, I climbed mountains, I even found what I believed to be the fabled well of youth![/color]"
                            A small pause.
                            A smirk forms on Seki's face.
                            He winks at you.
                            "[color=brown]Turns out it was just an ordinary river spring, but you probably could have guessed that by taking a look at me, eh?[/color]"
                        [/p]
                        [p]
                            The old man bursts into laughter, which quickly devolves into a coughing fit.
                            The smile is wiped off his face.
                            Hacking and wheezing, he spits a distinctly red-colored wad of phlegm from his beak onto the ground.
                            You fear for his well-being, the bird visibly hurting, but the moment he catches his breath,
                            he turns towards you, smile plastered across his face once more.
                            You don't know whether or not he's [i]acting[/i] tough.
                        [/p]
                        [p]
                            "[color=brown]Don't worry about me.[/color]"
                            Seki says, as if that's supposed to comfort you.
                            "[color=brown]Just a common cold.
                            Nothin' more.[/color]"
                            You mention that he has the [b]cure[/b] for that.
                            He once made you feel [b]much[/b] better with just a small potion.
                            The owl looks away.
                            All playfulness vanishes from his face, a disconcerting seriousness taking its place.
                            Tears form at the corners of his eyes.
                            He swallows deeply.
                            "[color=brown]It's not the kind of cold that can be cured.[/color]"
                        [/p]
                        [p]
                            The old man pokes a feathery finger underneath his glasses to wipe his eyes, in order to pretend he wasn't crying.
                            He turns towards you once more, a shaky, obviously faked grin on his face.
                            You're still stuck trying to process what he just said.
                            Is Seki going to...die?
                            The owl notices your confusion.
                            He tries to come up with a way to break the grim mood that has fallen upon the conversation, but you can see him visibly struggling for words.
                        [/p]
                        [p]
                            The bird utters a loud, depressing sigh.
                            "[color=brown]Anyway, off you go.[/color]"
                            He speaks, dismissing you with a wave of his hand, before turning around and beginning to walk away at a slow pace.
                            "[color=brown]I'll be in the city for the next few days, but be sure to stop by here sometime before next week, you hear?
                            I want to see my little [b]${ctrl.gender() === GenderEnum.MALE ? "man" : "woman"}[/b] one last time before...[/color]"
                            Stopping mid-sentence, Seki halts his slow walking for a moment.
                            He sadly snorts his nose, before silently disappearing into the darkness,
                            either to tend to his wounds, or to lament in solitude.
                        [/p]
                        [p]
                            Heartbroken, you hang your head and barely refrain from crying as you walk out of the old owl's shop.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.buyContinue.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.buyContinue.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiBuyContinue";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.buy.continued()) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.buyContinue.change();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.buy.continued()) {
            return;
        }

        next.registerListeners();

        if (ctrl.buyContinue.continued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\HamletDay2\SekiWorkshop\shop\SekiWorkshopBuyContinue.js

// scenes\HamletDay2\SekiWorkshop\entrance\SekiWorkshopEntrance.js

/**
 * Entrance section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopEntrance(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "entranceContinueButton";

    var toFree = new SekiWorkshopFree(ctrl);
    var toBuy = new SekiWorkshopBuy(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[st]Seki's Workshop[/st]
                        [p]
                            You enter the workshop of Seki, the owl.
                            This kind old man has helped you through some tough times in the past.
                            In some ways, you consider him the father you never had.
                            On the other hand, he's more of a [i]fence[/i] that you sell stuff you've stolen to.
                            In that regard, you suppose he's somewhat of a [i]bad[/i] influence.
                        [/p]
                        [p]
                            The workshop itself is [i]dark[/i], barely illuminated.
                            Being an owl, Seki prefers pitch-blackness above all,
                            keeping just a few candles around to prevent his customers from knocking over any of the potions he's brewed.
                            As a kobold, darkness doesn't phase you.
                            Your nightvision is superb, a fact which has significantly aided your criminal career thus far.
                            You deftly manoeuvre around the various tables and displays, towards the wooden counter,
                            where you ring a small bell to summon your elderly comrade from the depths of his shop.
                        [/p]
                        [p]
                            The old man is quite the accomplished alchemist.
                            There isn't a potion he [i]doesn't[/i] know how to brew.
                            Rumor has it that the owl used to be an advisor to the single most influential person in the entire world, the Dragon Emperor himself.
                            You've never quite asked him about it, and he hasn't told you, so you figure it's one of those things that are best left unmentioned.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the alternate content of this section.
     * @returns {string} The content.
     */
    function buildAltContent() {
        var name = ctrl.name();
        var toReturn = `[st]Seki's Workshop[/st]
                        [p]
                            As soon as the door to the barely illuminated workshop closes behind you,
                            a comforting feeling of intense [b]safety[/b] washes over you.
                            It touches you, to know that [b]someone[/b] actually [b]cares[/b] about you.
                            Your eyes water up.
                            You grab Seki's feathery leg, cuddle up against it and burst out into tears,
                            letting go all of the emotions you've been bottling up since the start of your capture.
                        [/p]
                        [p]
                            The big bird struggles to take a knee,
                            but once he manages to lower himself to your eye-level,
                            he wraps his winged arms around you, embracing you in a tender hug,
                            letting you rest your weeping head on his age-old shoulder while you bawl your eyes out.
                            "[color=brown]Shhhh...there, there.[/color]" he consolingly whispers to you, gently rubbing your bare back to calm you down.
                            "[color=brown]The bad men can't hurt you anymore.
                            You're safe here, with me.
                            Everything's going to be okay.[/color]"
                        [/p]
                        [p]
                            The avian lets you cry for as long as you need to.
                            For several minutes, you find yourself relaxing in Seki's clutches, your bountiful tears slowly coming to a halt.
                            Once again, the elderly owl proves that he's the closest thing to a father you'll ever have.
                        [/p]
                        [p]
                            As you begin to recover from the traumatic night and a half you've been through,
                            Seki reaches into the pouch hanging off his neck.
                            After fiddling around for a bit, he produces a recurring present, something he's given you [b]dozens[/b] of times before.
                            A single, shiny ${global.kobold.inventory.createItemWithTooltip(new Lockpick())}.
                            "[color=brown]Look here, what I have for you.
                            Remember this?[/color]"
                            Lifting your head from his shoulder, you give the bird a meek nod.
                            Breaking his caring embrace, he places the trinket into your hand, using his feathery talon to wrap your fingers around it tightly.
                            "[color=brown]It's all yours, my precious little ${name}.
                            Just like when you were young.[/color]"
                        [/p]
                        [p]
                            A small smile forms on your teary-eyed face.
                            Seki always knows exactly how to cheer you up.
                            With great difficulty, and a little help from you, he rises to his feet once more.
                            He grabs an empty coin pouch off one of his shelves, and hands it to you.
                            You gratefully wear it around your neck, as he wears his.
                        [/p]
                        [p]
                            "[color=brown]I'm sorry for yelling at you earlier.
                            Seeing you in the hands of [b]slaver scum[/b] ruffled my old feathers quite a bit.
                            But it's all over now.[/color]"
                            You ask about the money he used to [i]buy[/i] you.
                            Wasn't that a lot?
                            "[color=brown]Don't worry, little lizard.
                            I...won't be needing it anymore.[/color]"
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.entrance.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.entrance.continue();
            if (ctrl.gold() > ctrl.minBuyGold) {
                loadNextPart(toBuy);
            } else {
                loadNextPart(toFree);
            }
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiEntrance";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.arrival.continued()) {
            return "";
        }

        ctrl.bgm.loop();
        global.ui.applyTheme("hamlet_shop");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        if (global.kobold.history.shared.enslavement.noonTwo.boughtBySeki) {
            part += buildAltContent();
            part += ctrl.entrance.altChange();
        } else {
            part += buildContent();
        }
        part += buildChoice();
        part += `</div>`;
        part += toFree.build();
        part += toBuy.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.arrival.continued()) {
            return;
        }

        toFree.registerListeners();
        toBuy.registerListeners();

        if (ctrl.entrance.continued()) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\HamletDay2\SekiWorkshop\entrance\SekiWorkshopEntrance.js

// scenes\HamletDay2\SekiWorkshop\arrival\SekiWorkshopArrival.js

/**
 * Arrival section of the Workshop scene.
 * @param {SekiWorkshopController} controller The Seki controller.
 */
function SekiWorkshopArrival(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "arrivalContinueButton";

    var next = new SekiWorkshopEntrance(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You follow the eastern road towards Varanar,
                            making sure to keep your eyes peeled for any would-be assailants.
                            Luckily, your stroll is quite uneventful.
                            Bandits usually operate closer to nighttime.
                            Most of them must still be asleep.
                            It doesn't take you long to reach the small,
                            branching dirt path that'll lead you directly towards the hamlet.
                        [/p]
                        [p]
                            Approaching the small village, you cross paths with a couple of farmers.
                            You figure they're either making their way to their respective fields, or heading to Varanar for whatever reason.
                            They don't seem to be carrying any goods for sale, not that it's any of your business.
                            The humans are too busy speaking to one another to pay you much mind.
                            Shrugging, you continue along your journey.
                        [/p]
                        [p]
                            Around noon, you arrive at the hamlet.
                            The sun is high up in the sky, although the temperature remains somewhat frigid.
                            The settlement you have entered considers of nothing but a few meagre houses, a [i]breeding farm[/i], 
                            and a single shop, ran by an old friend of yours.
                            That last place is where you decide to head towards first.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.arrival.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.arrival.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "sekiArrival";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (global.kobold.history.shared.enslavement.noonTwo.boughtBySeki) {
            ctrl.arrival.continue();
            return next.build();
        }

        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        next.registerListeners();

        if (ctrl.arrival.continued() || global.kobold.history.shared.enslavement.noonTwo.boughtBySeki) {
            return;
        }

        registerContinueListener();
    };
}

// END scenes\HamletDay2\SekiWorkshop\arrival\SekiWorkshopArrival.js

// scenes\HamletDay2\SekiWorkshop\SekiWorkshopController.js

/**
 * Controller for the Home scene.
 * @param {string} sceneId The id of the scene.
 */
function SekiWorkshopController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var id = sceneId;
    var genderId = "gender";
    var autoSaveId = "autoSave";
    var goldId = "gold";
    var continueId = "continue";
    var underwearId = "underwear";
    var pantsId = "pants";
    var braId = "bra";
    var shirtId = "shirt";
    var nameId = "name";
    var healthId = "health";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}
    function EntranceController(key) {
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
            global.kobold.history.shared.seki.knowsDying = true;
            global.kobold.history.shared.seki.hamletHadMoney = global.kobold.inventory.coins !== 0;
        };
        this.continued = function () {
            return global.kobold.history.has(id, key);
        };
        var altChangeKey = key + "change";
        this.altChange = function () {
            global.kobold.history.doIfNotSet(id, altChangeKey, true, function () {
                global.kobold.status.mental.increase(15, "Hugging Seki");
                global.kobold.inventory.bag.addMisc(new Lockpick());
            });
            return global.ui.change.buildNotification([
                new Change("Cheered up", "Sanity", +15),
                new Change("Free lockpick", global.kobold.inventory.createItemWithTooltip(new Lockpick(), true), +1)
            ]);
        };
    }

    function FreeController(key) {
        ContinueController.call(this, id, key);
        var changeKey = key + "change";
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeKey, true, function () {
                global.kobold.status.mental.decrease(20, "Bad news has wings");
                global.kobold.inventory.bag.addMisc(new Lockpick());
            });
            return global.ui.change.buildNotification([
                new Change("Bad news", "Sanity", -20),
                new Change("Free lockpick", global.kobold.inventory.createItemWithTooltip(new Lockpick(), true), +1)
            ]);
        };
        var altChangeKey = key + "change";
        this.altChange = function () {
            global.kobold.history.doIfNotSet(id, altChangeKey, true, function () {
                global.kobold.status.mental.decrease(20, "Bad news has wings");
            });
            return global.ui.change.buildNotification([
                new Change("Bad news", "Sanity", -20)
            ]);
        };
    }

    function BuyController(key) {
        var that = this;
        ContinueController.call(this, id, key);

        var shopItemKey = key + "Items";
        var shopGoldKey = key + "Gold";
        var initialShopItems = [
            new ItemAmount(1, new Dagger()),
            new ItemAmount(1, new LinenBra()),
            new ItemAmount(1, new KoboldUnderwear()),
            new ItemAmount(1, new LeatherPants()),
            new ItemAmount(1, new PaddedLeatherShirt()),
            new ItemAmount(1, new Rope()),
            new ItemAmount(1, new SmallMirror()),
            new ItemAmount(4, new Lockpick()),
            new ItemAmount(1, new AgilityPotion()),
            new ItemAmount(1, new CharismaPotion()),
            new ItemAmount(1, new EndurancePotion()),
            new ItemAmount(1, new IntelligencePotion()),
            new ItemAmount(1, new LuckPotion()),
            new ItemAmount(1, new StrengthPotion()),
            new ItemAmount(1, new RejuvenationPotion()),
            new ItemAmount(2, new mPlus()),
            new ItemAmount(2, new Apple()),
            new ItemAmount(1, new HeartyMeal())
        ];
        var sellmod = 0.7;
        var buymod = 1.0;

        function sellListener(item) {
            var itemAmounts = that.shopItems();
            var added = false;
            for (var i = 0; i < itemAmounts.length && !added; i++) {
                if (itemAmounts[i].item.id === item.id) {
                    itemAmounts[i].amount++;
                    added = true;
                }
            }
            if (!added) {
                itemAmounts.push(new ItemAmount(1, item));
            }
            that.updateCoins();
            that.updateShopItems(itemAmounts);
        }

        function buyListener(location) {
            var oldCoins = that.coins();
            that.updateCoins();
            var newCoins = that.coins();
            var itemAmounts = that.shopItems();
            itemAmounts[location].amount--;
            that.updateShopItems(itemAmounts);
            global.kobold.history.shared.seki.moneySpent += oldCoins - newCoins;
        }

        this.getGenerator = function () {
            return new MerchantInventoryGenerator("SekiShop", that.shopItems(), that.coins(), sellmod, buymod, that.continued(), sellListener, buyListener);
        };
        this.coins = function () {
            global.kobold.history.setIfNotSet(id, shopGoldKey, global.kobold.inventory.coins);
            return global.kobold.history.getKey(id, shopGoldKey);
        };
        this.updateCoins = function () {
            global.kobold.history.setKey(id, shopGoldKey, global.kobold.inventory.coins);
        };
        this.shopItems = function () {
            global.kobold.history.setIfNotSet(id, shopItemKey, initialShopItems);
            var jsonItems = global.kobold.history.getKey(id, shopItemKey);
            var items = global.kobold.inventory.constructItemAmountListFromMemory(jsonItems);
            return items;
        };
        this.updateShopItems = function (newItems) {
            global.kobold.history.setKey(id, shopItemKey, newItems);
        };
    }

    function BuyContinueController(id, key) {
        this.continue = function () {
            global.kobold.history.setKey(id, key, true);
        };
        this.continued = function () {
            // Version 2.11 (Pitchfork) introduced a bug where the key used for the BuyContinueController was the id of the scene.
            // This fix ensures saves will not retroactively break.
            return global.kobold.history.has(id, key) || global.kobold.history.has(id, id);
        };
        var changeKey = key + "change";
        this.change = function () {
            global.kobold.history.doIfNotSet(id, changeKey, true, function () {
                global.kobold.status.mental.decrease(20, "Bad news has wings");
            });
            return global.ui.change.buildNotification([
                new Change("Bad news", "Sanity", -20)
            ]);
        };
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.folderName = "HamletDay2";
    this.breedingSceneName = "BreedingFarm";
    this.farmHomeSceneName = "FarmerHouse";
    this.wellSceneName = "HamletWell";
    this.minBuyGold = 50;
    this.arrival = new ContinueController(id, "arrival");
    this.entrance = new EntranceController("entrance");
    this.free = new FreeController("free");
    this.buy = new BuyController("buy");
    this.buyContinue = new BuyContinueController(id, "buyContinue");

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /*
     * Autosaves the game if necessary.
     */
    this.autosave = function () {
        global.kobold.history.doIfNotSet(id, autoSaveId, true, function () {
            global.saveManager.autoSave();
        });
    };

    /**
     * Signals the scene has been continued.
     */
    this.continue = function () {
        global.kobold.history.setKey(id, continueId, true);
    };

    /**
     * Returns whether or not the scene has continued.
     * @returns {boolean} True if the scene has continued, false otherwise.
     */
    this.continued = function () {
        return global.kobold.history.has(id, continueId);
    };

    this.gold = function () {
        global.kobold.history.setIfNotSet(id, goldId, global.kobold.inventory.coins);
        return global.kobold.history.getKey(id, goldId);
    };

    this.pants = function () {
        global.kobold.history.setIfNotSet(id, pantsId, global.kobold.inventory.equipment.pants);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, pantsId));
    };

    this.bra = function () {
        global.kobold.history.setIfNotSet(id, braId, global.kobold.inventory.equipment.bra);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, braId));
    };

    this.shirt = function () {
        global.kobold.history.setIfNotSet(id, shirtId, global.kobold.inventory.equipment.shirt);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, shirtId));
    };

    this.underwear = function () {
        global.kobold.history.setIfNotSet(id, underwearId, global.kobold.inventory.equipment.underwear);
        return global.kobold.inventory.equipment.buildGearFromHistory(global.kobold.history.getKey(id, underwearId));
    };

    this.gender = function () {
        global.kobold.history.setIfNotSet(id, genderId, global.kobold.body.getBaseGender());
        return global.kobold.history.getKey(id, genderId);
    };

    this.name = function () {
        global.kobold.history.setIfNotSet(id, nameId, global.kobold.name);
        return global.kobold.history.getKey(id, nameId);
    };

    this.health = function () {
        global.kobold.history.setIfNotSet(id, healthId, global.kobold.status.physical.get());
        return global.kobold.history.getKey(id, healthId);
    };

    this.bgm = new AudioController(id, "res/audio/seki/sadness_cosmo.mp3", 100);
}

// END scenes\HamletDay2\SekiWorkshop\SekiWorkshopController.js

// scenes\HamletDay2\SekiWorkshop\SekiWorkshop.js

/**
 * Seki's Workshop. Starting scene of the Hamlet.
 */
function SekiWorkshop() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var sceneId = "SekiWorkshop";
    var sceneName = "Seki's Workshop";
    var sceneSubfolder = "HamletDay2";
    var ctrl = new SekiWorkshopController(sceneId);
    var arrival = new SekiWorkshopArrival(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Sets all the required global variables such as scene id, scene name,
     * scene stack and theme.
     */
    function setGlobals() {
        global.currentScene = that.id;
        global.currentSceneName = that.name;
        global.currentSceneFolder = that.subfolder ? that.subfolder : "";
        global.kobold.history.addToSceneStack(that.id);
    }

    /**
     * Builds the tab as a HTML string.
     * @returns {string} The tab, as a HTML string.
     */
    function buildTab() {
        var tab = global.ui.buildGenericHeader();
        tab += global.parser.parse(`[t]hamlet[/t]`);
        tab += arrival.build();
        tab += global.ui.buildGenericFooter();
        return tab;
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = sceneId;
    this.name = sceneName;
    this.subfolder = sceneSubfolder;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Loads this scene.
     */
    this.load = function () {
        setGlobals();
        var tab = buildTab();
        global.ui.loadToMain(tab);
        arrival.registerListeners();
        ctrl.autosave();
    };
}

global.sceneLoader.queueRegister(function () {
    var scene = new SekiWorkshop();
    global.sceneLoader.registerScene(scene.id, scene);
});

// END scenes\HamletDay2\SekiWorkshop\SekiWorkshop.js



// END SCENE SekiWorkshop

